@@ -1,24 +1,23 @@
 p_nca_ce_vrs <-
 function (loop.data, bn.data) {
-  x <- loop.data$x
-  y <- loop.data$y
   flip.x <- loop.data$flip.x
   flip.y <- loop.data$flip.y
   
   # Find the points on the ceiling ("PEERS")
-  peers       <- p_peers(loop.data, TRUE)
+  peers       <- p_peers(loop.data, vrs=TRUE)
 
   line        <- p_vrs_line(loop.data, peers, flip.x, flip.y)
-  ceiling     <- p_ce_ceiling(loop.data, peers, flip.x, flip.y, "vrs")
+  ceiling     <- p_ce_ceiling(loop.data, peers, "vrs")
   effect      <- ceiling / loop.data$scope.area
   ineffs      <- p_ineffs_ce(loop.data, peers)
   bottleneck  <- p_bottleneck_ce(loop.data, bn.data, peers, "vrs")
+  fit         <- get_fit(ceiling, loop.data$ce_fdh_ceiling)
 
   return(list(line=line,
               slope=NA, intercept=NA,
               ceiling=ceiling, effect=effect,
-              ineffs=ineffs, above=0,
-              bottleneck=bottleneck))
+              above=0, accuracy=100, fit=fit,
+              ineffs=ineffs, bottleneck=bottleneck))
 }
 
 p_vrs_line <-
